Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(429)

Unified Diff: third_party/WebKit/Source/core/input/PointerEventManager.h

Issue 1968653005: Set width=height=1 of mouse like pointer events (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/input/PointerEventManager.h
diff --git a/third_party/WebKit/Source/core/input/PointerEventManager.h b/third_party/WebKit/Source/core/input/PointerEventManager.h
index 873c637bc69a6f75f0ef1aad05f93fb5228d5de7..6654325f9505dda7191bd435f384082625e52fbd 100644
--- a/third_party/WebKit/Source/core/input/PointerEventManager.h
+++ b/third_party/WebKit/Source/core/input/PointerEventManager.h
@@ -37,7 +37,7 @@ public:
WebInputEventResult handleTouchEvents(
const PlatformTouchEvent&);
// Sends node transition events mouseout/leave/over/enter to the
// corresponding targets. This function sends pointerout/leave/over/enter
// only when isFrameBoundaryTransition is true which indicates the
// transition is over the document boundary and not only the elements border
@@ -45,10 +45,10 @@ public:
// then the event is a compatibility event like those created by touch
// and in that case the corresponding pointer events will be handled by
// sendTouchPointerEvent for example and there is no need to send pointer
// transition events. Note that normal mouse events (e.g. mousemove/down/up)
// and their corresponding transition events will be handled altogether by
// sendMousePointerEvent function.
- void sendMouseAndPossiblyPointerNodeTransitionEvents(
+ void sendMouseAndPossiblyPointerBoundaryEvents(
Node* exitedNode,
Node* enteredNode,
const PlatformMouseEvent&,
@@ -104,7 +104,7 @@ private:
// Returns whether the event is consumed or not.
WebInputEventResult sendTouchPointerEvent(EventTarget*, PointerEvent*);
- void sendNodeTransitionEvents(
+ void sendBoundaryEvents(
EventTarget* exitedTarget,
EventTarget* enteredTarget,
PointerEvent*,
@@ -123,8 +123,8 @@ private:
bool sendMouseEvent = false);
// Processes the capture state of a pointer, updates node under
// pointer, and sends corresponding transition events for pointer if
// setPointerPosition is true. It also sends corresponding transition events
// for mouse if sendMouseEvent is true.
void processCaptureAndPositionOfPointerEvent(
PointerEvent*,
@@ -37,7 +37,7 @@ public:
WebInputEventResult handleTouchEvents(
const PlatformTouchEvent&);
- // Sends node transition events mouseout/leave/over/enter to the
+ // Sends boundary events mouseout/leave/over/enter to the
// corresponding targets. This function sends pointerout/leave/over/enter
// only when isFrameBoundaryTransition is true which indicates the
@@ -45,10 +45,10 @@ public:
// and in that case the corresponding pointer events will be handled by
// sendTouchPointerEvent for example and there is no need to send pointer
- // transition events. Note that normal mouse events (e.g. mousemove/down/up)
- // and their corresponding transition events will be handled altogether by
+ // boundary events. Note that normal mouse events (e.g. mousemove/down/up)
+ // and their corresponding boundary events will be handled altogether by
// sendMousePointerEvent function.
@@ -123,8 +123,8 @@ private:
bool sendMouseEvent = false);
// Processes the capture state of a pointer, updates node under
- // pointer, and sends corresponding transition events for pointer if
- // setPointerPosition is true. It also sends corresponding transition events
+ // pointer, and sends corresponding boundary events for pointer if
+ // setPointerPosition is true. It also sends corresponding boundary events
// for mouse if sendMouseEvent is true.
void processCaptureAndPositionOfPointerEvent(

Powered by Google App Engine
This is Rietveld 408576698